@@ -92,7 +92,10 @@ main ( int argc, char ** argv )
   gboolean capplet_mode = FALSE;
   int i;
 
-  /* Initialize the i18n stuff */
+  /* Initialize the i18n stuff (the call to 'libgtop' catalog is to translate
+   * the strings that are imported from libtop libs
+   */
+  bindtextdomain ("libgtop", GNOMELOCALEDIR);
   bindtextdomain (PACKAGE, GNOMELOCALEDIR);
   textdomain (PACKAGE);
 
@@ -510,7 +513,8 @@ static void do_logo_box(GtkWidget * box)
   contrib_label = gtk_label_new(_("GNOME contributors:"));
 
   style = gtk_style_new ();
-  font = gdk_font_load (_("-Adobe-Helvetica-Medium-R-Normal--*-180-*-*-*-*-*-*"));
+  /* fontset used by guname; adapt it if your language requires it */
+  font = gdk_fontset_load (_("-Adobe-Helvetica-Medium-R-Normal--*-180-*-*-*-*-*-*"));
 
   if (font) {
     gdk_font_unref (style->font);
@@ -586,6 +590,7 @@ static void do_list_box(GtkWidget * box)
   GtkCList * list;
   GtkWidget *sw;
   const gchar * titles[] = { N_("Category"), N_("Your System") };
+  gint width, height;
 
   titles[0]=_(titles[0]);
   titles[1]=_(titles[1]);
@@ -610,10 +615,12 @@ static void do_list_box(GtkWidget * box)
   gtk_signal_connect(GTK_OBJECT(list), "button_press_event",
                      GTK_SIGNAL_FUNC(list_clicked_cb), NULL);
 
-  fill_clist(list, descriptions, info, end_system_info);
+  fill_clist(list, descriptions, info, end_system_info, &width, &height);
 
   gtk_clist_thaw(list);
 
+  gtk_widget_set_usize(GTK_WIDGET(sw), width, height);
+
   gtk_container_add(GTK_CONTAINER(box), GTK_WIDGET(sw));
 }
 
