@@ -330,7 +330,7 @@ static void ide_stat_drive(char *drive, int fd, GtkWidget *notebook)
 	
 	gtk_signal_connect(GTK_OBJECT(cl), "select_row", (GtkSignalFunc)modify_drive,
 			   GINT_TO_POINTER(id+(drive[2]<<8)) );
-	gtk_container_add(GTK_CONTAINER(vbox), GTK_WIDGET(cl));
+	gtk_container_add(GTK_CONTAINER(vbox), GTK_WIDGET(sw));
 	gtk_widget_show_all(GTK_WIDGET(sw));
 	gtk_widget_show(vbox);
 }
